TelegramBot class

@date 18/9/21 describe:

Constructors

TelegramBot()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendFile(File file, {String? caption}) → void
sendMessage(String message, {int? chatId}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

chatId ↔ int?
getter/setter pair
instance → TelegramBot
no setter
teledart ↔ TeleDart?
getter/setter pair

Static Methods

init(String token, int chatID) → void