JSONOutputStyle class

Constructors

JSONOutputStyle({Color commaColor = Colors.black, Color squareBracketsColor = Colors.black, Color braceColor = Colors.black, Color colonColor = Colors.black, Color keyColor = Colors.pink, Color stringColor = Colors.green, Color boolColor = Colors.orange, Color numColor = Colors.blue, Color nullColor = Colors.brown, double fontSize = 10, FontWeight fontWeight = FontWeight.w400, Color quotationColor = Colors.black, double height = 1.2})
const

Properties

boolColor → Color
布尔值的颜色
final
braceColor → Color
花括号颜色
final
colonColor → Color
冒号颜色
final
commaColor → Color
逗号颜色
final
fontSize → double
字体大小
final
fontWeight → FontWeight
字体粗细
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
行高
final
keyColor → Color
字典key的颜色
final
nullColor → Color
null的颜色
final
numColor → Color
数值的颜色
final
quotationColor → Color
引号颜色
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
squareBracketsColor → Color
中括号颜色
final
stringColor → Color
字符串的颜色
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited