InputPanelField class

Inheritance

Constructors

InputPanelField({Key? key, String? text, bool obscureText = false, BoxDecoration? decoration, int maxLines = 1, double height = 38, TextInputAction textInputAction = TextInputAction.done, Color? normalColor, Color? focusColor = Colors.transparent, ValueChanged<String>? onSubmitted, TextEditingController? controller, String? hintText, FocusNode? focusNode, Widget? leftWidget, Color? backGroundColor, bool leftIconEnable = false, bool nonDecoration = false, double contentPadding = 12, List<TextInputFormatter>? inputFormatters, VoidCallback? onEditingComplete, VoidCallback? cancelCallBack, FocusScopeNode? scopeNode, int? maxLength, String? exceedLimitTip, TextInputType keyboardType = TextInputType.text, bool enable = true, Color? cursorColor, EdgeInsetsGeometry? padding})
InputPanelField.noneDecoration({Key? key, String? text, bool obscureText = false, BoxDecoration? decoration, int maxLines = 1, double height = 38, TextInputAction textInputAction = TextInputAction.next, Color? normalColor, Color? focusColor = Colors.transparent, ValueChanged<String>? onSubmitted, TextEditingController? controller, String? hintText, FocusNode? focusNode, Widget? leftWidget, Color? backGroundColor, bool leftIconEnable = false, bool nonDecoration = true, TextInputType keyboardType = TextInputType.text, double contentPadding = 12, VoidCallback? onEditingComplete, List<TextInputFormatter>? inputFormatters, VoidCallback? cancelCallBack, int? maxLength, FocusScopeNode? scopeNode, String? exceedLimitTip, bool enable = true, Color? cursorColor, EdgeInsetsGeometry? padding})
InputPanelField.search({Key? key, String? text, bool obscureText = false, BoxDecoration? decoration, int maxLines = 1, double height = 38, TextInputAction textInputAction = TextInputAction.search, Color? normalColor, Color? focusColor = Colors.transparent, ValueChanged<String>? onSubmitted, TextEditingController? controller, String? hintText, FocusNode? focusNode, Widget? leftWidget, bool leftIconEnable = true, bool nonDecoration = false, Color? backGroundColor, TextInputType keyboardType = TextInputType.text, VoidCallback? onEditingComplete, double contentPadding = 18, List<TextInputFormatter>? inputFormatters, int? maxLength, VoidCallback? cancelCallBack, FocusScopeNode? scopeNode, String? exceedLimitTip, bool enable = true, Color? cursorColor, EdgeInsetsGeometry? padding})

Properties

backGroundColor → Color?
final
cancelCallBack → VoidCallback?
final
contentPadding → double
final
controller → TextEditingController?
final
cursorColor → Color?
final
decoration → BoxDecoration?
final
enable → bool
final
exceedLimitTip → String?
final
focusColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
hintText → String?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
leftIconEnable → bool
final
leftWidget → Widget?
final
maxLength → int?
final
maxLines → int
final
nonDecoration → bool
final
normalColor → Color?
final
obscureText → bool
final
onEditingComplete → VoidCallback?
final
onSubmitted → ValueChanged<String>?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeNode → FocusScopeNode?
final
text → String?
final
textInputAction → TextInputAction
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _InputPanelFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited